/*
 * config.c: Web video plugin for the Video Disk Recorder
 *
 * See the README file for copyright information and how to reach the author.
 *
 * $Id$
 */

#include <stdlib.h>
#include <string.h>
#include "config.h"

cWebvideoConfig *webvideoConfig = new cWebvideoConfig();

cWebvideoConfig::cWebvideoConfig() {
  server = NULL;
  port = NULL;
  downloadPath = NULL;
  preferXine = true;
  for (int i=0; i<20; i++) {
    daemonArgs[i] = NULL;
  }
}

cWebvideoConfig::~cWebvideoConfig() {
  if (server)
    free(server);
  if (port)
    free(port);
  if (downloadPath)
    free(downloadPath);
}

void cWebvideoConfig::SetServer(const char *serveraddr) {
  if (server)
    free(server);

  server = serveraddr ? strdup(serveraddr) : NULL;
}

const char *cWebvideoConfig::GetServer() {
  return server;
}

void cWebvideoConfig::SetPort(const char *serverport) {
  if (port)
    free(port);

  port = serverport ? strdup(serverport) : NULL;
}

const char *cWebvideoConfig::GetPort() {
  return port;
}

void cWebvideoConfig::SetDownloadPath(const char *path) {
  if (downloadPath)
    free(downloadPath);
  downloadPath = path ? strdup(path) : NULL;
}

const char *cWebvideoConfig::GetDownloadPath() {
  return downloadPath;
}

void cWebvideoConfig::SetDaemonCmd(const char *cmd) {
  int i = 0;
  while (daemonArgs[i]) {
    free(daemonArgs[i]);
    daemonArgs[i] = NULL;
    i++;
  }

  char *cmdcpy = strdup(cmd);
  char *tok = strtok(cmdcpy, " ");
  i = 0;
  while (tok && (i < 20)) {
    daemonArgs[i++] = strdup(tok);
    tok = strtok(NULL, " ");
  }
  free(cmdcpy);
}

char * const *cWebvideoConfig::GetDaemonCmd() {
  return daemonArgs;
}

void cWebvideoConfig::SetPreferXineliboutput(bool pref) {
  preferXine = pref;
}

bool cWebvideoConfig::GetPreferXineliboutput() {
  return preferXine;
}
