/*
 * history.c: Web video plugin for the Video Disk Recorder
 *
 * See the README file for copyright information and how to reach the author.
 *
 * $Id$
 */

#include "history.h"

// --- cHistoryObject -----------------------------------------------------

cHistoryObject::cHistoryObject(const char *xml, int ID) {
  if (xml)
    osdxml = strdup(xml);
  else
    osdxml = NULL;
  id = ID;
}

cHistoryObject::~cHistoryObject() {
  if (osdxml)
    free(osdxml);
}

const char *cHistoryObject::GetOSD() {
  return osdxml;
}

int cHistoryObject::GetID() {
  return id;
}

// --- cHistory ------------------------------------------------------------

cHistory::cHistory() {
  current = NULL;
}

void cHistory::Clear() {
  current = NULL;
  cList<cHistoryObject>::Clear();
}

void cHistory::TruncateAndAdd(cHistoryObject *page) {
  cHistoryObject *last = Last();
  while ((last) && (last != current)) {
    Del(last);
    last = Last();
  }

  Add(page);
  current = Last();
}

void cHistory::Reset() {
  current = NULL;
}

cHistoryObject *cHistory::Current() {
  return current;
}

cHistoryObject *cHistory::Home() {
  current = First();
  return current;
}

cHistoryObject *cHistory::Back() {
  if (current)
    current = Prev(current);
  return current;
}

cHistoryObject *cHistory::Forward() {
  cHistoryObject *next;
  if (current) {
    next = Next(current);
    if (next)
      current = next;
  } else {
    current = First();
  }
  return current;
}
